@@ -5,9 +5,9 @@ use strict;
 use warnings;
 use Carp;
 use LWP::Protocol;
-use Guard;
+use Scope::Guard qw(guard);
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 $VERSION = eval $VERSION;
 
 our @Protocols = qw(http https);
